<?php

namespace Drupal\visitors;

use Drupal\Core\Cache\CacheBackendInterface;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\Plugin\DefaultPluginManager;

/**
 * Plugin manager for visitor action plugins.
 */
class VisitorsActionPluginManager extends DefaultPluginManager {

  /**
   * Constructs a VisitorsActionPluginManager object.
   *
   * @param \Traversable $namespaces
   *   An object that implements \Traversable which contains the root paths
   *   keyed by the corresponding namespace to look for plugin implementations.
   * @param \Drupal\Core\Cache\CacheBackendInterface $cache_backend
   *   Cache backend instance to use.
   * @param \Drupal\Core\Extension\ModuleHandlerInterface $module_handler
   *   The module handler to invoke the alter hook with.
   */
  public function __construct(\Traversable $namespaces, CacheBackendInterface $cache_backend, ModuleHandlerInterface $module_handler) {
    parent::__construct(
      'Plugin/VisitorsAction',
      $namespaces,
      $module_handler,
      'Drupal\visitors\VisitorsActionPluginInterface',
      'Drupal\visitors\Attribute\VisitorsAction'
    );

    $this->alterInfo('visitors_action_info');
    $this->setCacheBackend($cache_backend, 'visitors_action_plugins');
  }

}
